# Portfolio Risk Management Test.R
# 
while (!is.null(dev.list()))  dev.off() # Clear old plots
rm(list = ls())  # Take out the Environment "trash"
cat("\014") # Clear Console, making error checking easier.
par(family = 'Times New Roman') # Globally set fonts for graphs
# BatchGetSymbols - pulling sets of stock data from internet
# quantmod - pulling stock data from internet (may or may not work)
#   as internet protocols constantly change
PackagesToLibrary <- c("quantmod", "openxlsx", "xts", "rootSolve", "zoo", 
  "date", "PerformanceAnalytics", "stats", "RColorBrewer", "Hmisc", #"SDMTools"
  "weights", "BatchGetSymbols", "Weighted.Desc.Stat", "beepr") # Libraries
if (length(setdiff(PackagesToLibrary, rownames(installed.packages()))) > 0) {
  install.packages(setdiff(PackagesToLibrary, rownames(installed.packages())))  
} # Make sure libraries are installed on this computer
# Load and attach libraries
lapply(PackagesToLibrary,library,character.only = TRUE) 
rm(PackagesToLibrary)
# Sector ETFs
# XLK: SP 500 Sector ETF: Technology
# XLF: SP 500 Sector ETF: Financial
# XLI: SP 500 Sector ETF: Industrial
# XLY: SP 500 Sector ETF: Consumer Discretionary
# XLB: SP 500 Sector ETF: Materials
# XLV: SP 500 Sector ETF: Healthcare
# XLU: SP 500 Sector ETF: Utilities
# XLP: SP 500 Sector ETF: Consumer Staples
# XLE: SP 500 Sector ETF: Energy
#
# Inputs
#
# Color or gray scale
Color <- FALSE
# Daily data range
StartDate <- as.Date('2013-12-31') # Earliest 01/03/2007
EndDate <- as.Date('2023-12-12')
#
# Generated Graphs
#
TOTALRETURNS <- FALSE
PERIODICRETURNS <- FALSE
ROLLINGMEANS <- TRUE
ROLLINGSD <- FALSE
ROLLINGBETA <- FALSE
VOLBEN <- FALSE
# Fix y-axis
# FIXYAXISTRETURNS <- TRUE
# MINTRETURNS <- 0.0
# MAXTRETURNS <- 14.0
FIXYAXISMEANSPRETURNS <- FALSE
MINPRETURNS <- 0.0
MAXPRETURNS <- 15.0
FIXYAXISMEANS <- FALSE
MINMEANS <- 0.0
MAXMEANS <- 15.0
# FIXYAXISSD <- FALSE
# MINSD <- 1.0
# MAXSD <- 15
# FIXYAXISBETA <- FALSE
# MINBETA <- 0.0
# MAXBETA <- 2.0
FIXYAXISVOLBEN <- TRUE
MINVOLBEN <- 0.0
MAXVOLBEN <- 100.0
InstrumentType <- 'Stock'
# Stocks to analyze (Benchmark assumed to be first, up to 9 other names)
# Analysis of sector, large member, and smaller member
Tickers <- c('SPY', 'STLD', 'NOW', 'PHM', 'REGN', 'AAP', 'XYL', 'RTX', 'SYK', 'PSA')
Names <- c('SP 500', 'Steel Dynamics', 'Service Now', 'Pulte', 'Regeneron',
  'Advanced Auto', 'Xylem', 'Raytheon', 'Stryker', 'Public Storage')
#
# Other Tickers/Names explored
#
# Tickers <- c('SPY', 'XLF', 'JPM', 'RF')
# Names <- c('SP 500', 'Financial ETF', 'JP Morgan', 'Regions Financial Corp.')
# Tickers <- c('SPY', 'XLE', 'XOM', 'WMB')
# Names <- c('SP 500', 'Energy ETF', 'ExxonMobil', 'Williams')
# Analysis of sectors
# Tickers <- c('SPY', 'XLK', 'XLF', 'XLU', 'XLE')
# Names <- c('SP 500', 'Technology', 'Finance', 'Utilities', 'Energy')
# Analysis of all subsectors
# Tickers <- c('SPY', 'XLK', 'XLF', 'XLI', 'XLY', 'XLB', 'XLV', 'XLU', 'XLP',
#   'XLE')
# Names <- c('SP 500', 'Technology', 'Finance', 'Industrial',
#   'Cons. Discretionary', 'Materials', 'Healthcare', 'Utilities',
#   'Cons. Staples', 'Energy')
Lambda = 0.94 # Base case: 0.94 -- Weighting variable, 0.9999 Equal
# 1-Daily, 2-2nd trading day, 3-3rd trading day, 4-4th trading day, 
#  5-5th trading day, 6-Weekly (DayOfWeek), 7-Monthly 
Periodicity <- 6
# If 1/2 year: 1-126, 2-63, 3-42, 4-32, 5-25, 6-26, 7-6 (too short)
MinPeriods <- 36
PeriodInYears <- 0.5
DayOfWeek <- "Wednesday" # Only applies to 6-Weekly
# Only applies to 7-Monthly, -1=End of Month, 0=Beginning of Month
# 10=approximately mid-month
MonthAdjust <- 0
# Plot footers
SD = paste0(StartDate)
ED = paste0('-', EndDate)
L = paste0(',L=', Lambda)
MA = paste0('')
if (Periodicity == 1){
  P = paste0(', Daily')
  RollingWindow <- max(as.integer(PeriodInYears*252/Periodicity), MinPeriods) 
} else if (Periodicity == 2) { # Every 2nd trading day
  P = paste0(',2 Days')
  RollingWindow <- max(as.integer(PeriodInYears*252/Periodicity), MinPeriods) 
} else if (Periodicity == 3) { # Every 3rd trading day
  P = paste0(',3 Days')
  RollingWindow <- max(as.integer(PeriodInYears*252/Periodicity), MinPeriods) 
} else if (Periodicity == 4) { # Every 4th trading day
  P = paste0(',4 Days')
  RollingWindow <- max(as.integer(PeriodInYears*252/Periodicity), MinPeriods) 
} else if (Periodicity == 5) { # Every 5th trading day
  P = paste0(',5 Days')
  RollingWindow <- max(as.integer(PeriodInYears*252/Periodicity), MinPeriods) 
} else if (Periodicity == 6) { # Weekly
  P = paste0(',Weekly')
  RollingWindow <- max(as.integer(PeriodInYears*252/5), MinPeriods) 
} else if (Periodicity == 7) { # Monthly
  P = paste0(', Monthly')
  MA = paste0(',Adjust=', MonthAdjust)
  RollingWindow <- max(as.integer(PeriodInYears*252/21), MinPeriods) 
} 
RW = paste0(',RW=', RollingWindow)
sTitle = paste0(SD, ED, RW, L, P, MA)
#
# Estimate variety rolling statistics
#
# VOLBEN <- TRUE 
PORTFOLIO <- TRUE
PORTSIZE <- 'NA'
FIXYAXISTRETURNS <- TRUE
MINTRETURNS <- 0.0
MAXTRETURNS <- 14.0
FIXYAXISMEANSPRETURNS <- TRUE
MINPRETURNS <- -70.0
MAXPRETURNS <- 70.0
FIXYAXISMEANS <- TRUE
MINMEANS <- -5.25
MAXMEANS <- 5.25
FIXYAXISSD <- TRUE
MINSD <- 0.0
MAXSD <- 17.5
FIXYAXISBETA <- TRUE
MINBETA <- -3.0
MAXBETA <- 4.0
FIXYAXISVOLBEN <- TRUE
MINVOLBEN <- -20.0
MAXVOLBEN <- 80.0
Tickers <- c('SPY', 'STLD', 'NOW', 'PHM', 'REGN', 'AAP', 'XYL', 'RTX', 'SYK', 'PSA')
Names <- c('SP 500', 'Steel Dynamics', 'Service Now', 'Pulte', 'Regeneron',
  'Advanced Auto', 'Xylem', 'Raytheon', 'Stryker', 'Public Storage')
source('Stock Statistical Analysis.R')
# Produce plots
source('Rolling Plots.R')
#
# Diversification illustrations (PORTSIZE maximum = 10)
#
# Individual Stocks
#
# VOLBEN <- TRUE 
PORTFOLIO <- TRUE
InstrumentType <- 'Stock Portfolios'
TickerSet <- c('SPY', 'STLD', 'NOW', 'PHM', 'REGN', 'AAP', 'XYL', 'RTX', 'SYK', 'PSA')
NamesSet <- c('SP 500', 'Steel Dynamics', 'Service Now', 'Pulte', 'Regeneron',
           'Advanced Auto', 'Xylem', 'Raytheon', 'Stryker', 'Public Storage')
source('Incremental Portfolio.R')
#
# Sector ETFs
#
#  Master file
# K, F, I, Y, B, V, U, P, E (Sector Tickers)
# SPY: SP 500 ETF
# XLK: SP 500 Sector ETF: Technology
# XLF: SP 500 Sector ETF: Financial
# XLI: SP 500 Sector ETF: Industrial
# XLY: SP 500 Sector ETF: Consumer Discretionary
# XLB: SP 500 Sector ETF: Materials
# XLV: SP 500 Sector ETF: Healthcare
# XLU: SP 500 Sector ETF: Utilities
# XLP: SP 500 Sector ETF: Consumer Staples
# XLE: SP 500 Sector ETF: Energy
#
# VOLBEN <- TRUE
PORTFOLIO <- TRUE
PORTSIZE <- 'NA'
FIXYAXISTRETURNS <- TRUE
MINTRETURNS <- 0.0
MAXTRETURNS <- 7.0
FIXYAXISMEANSPRETURNS <- TRUE
MINPRETURNS <- -35.0
MAXPRETURNS <- 35.0
FIXYAXISMEANS <- TRUE
MINMEANS <- -3.5
MAXMEANS <- 3.5
FIXYAXISSD <- TRUE
MINSD <- 0.0
MAXSD <- 10.5
FIXYAXISBETA <- TRUE
MINBETA <- -1.0
MAXBETA <- 2.5
FIXYAXISVOLBEN <- TRUE
MINVOLBEN <- -20.0
MAXVOLBEN <- 80.0
InstrumentType <- 'Individual Sector ETFs'
Tickers <- c('SPY', 'XLK', 'XLF', 'XLI', 'XLY', 'XLB', 'XLV', 'XLU', 'XLP', 'XLE')
Names <- c('SP 500', 'Technology', 'Financial', 'Industrial', 'Cons Discretionary',
  'Materials', 'Healthcare', 'Utilities', 'Consumer Staples', 'Energy')
source('Stock Statistical Analysis.R')
# Produce plots
source('Rolling Plots.R')
# VOLBEN <- TRUE
PORTFOLIO <- TRUE
InstrumentType <- 'Sector ETF Portfolios'
TickerSet <- c('SPY', 'XLK', 'XLF', 'XLI', 'XLY', 'XLB', 'XLV', 'XLU', 'XLP', 'XLE')
NamesSet <- c('SP 500', 'Technology', 'Financial', 'Industrial', 'Cons Discretionary',
              'Materials', 'Healthcare', 'Utilities', 'Consumer Staples', 'Energy')
source('Incremental Portfolio.R')
beep(sound = 2, print('Finished'))
