# Batch Securities.R
#  
# NOTE: BatchGetSymbols does not load data in order!!!
# NOTE: "weekly" appears to only pull from week-end dates somehow
# NOTE: Need to just use daily and forward fill to create other periodicities
Frequency <- 'daily'  # 'daily', 'weekly', 'monthly', 'yearly'
Securities <- BatchGetSymbols(tickers = Tickers, # Symbol desired
  bench.ticker = "^GSPC", # SPY  # "^GSPC", # Benchmark (SP 500 for dates ?)  
  # src = "google", # Source: Yahoo or Google
  # as.Date('2010-01-01'), # Sys.Date()-365, start date in Date format
  first.date = StartDate, #Sys.Date()-365
  last.date = EndDate, #Sys.Date(),
  freq.data = Frequency,
#  how.to.aggregate = "last", # Crashes
  type.return = "log", # 'arit'
  do.fill.missing.prices = TRUE,
  thresh.bad.data = 0.9) # Percent of bad data allowed, if less, out
NTickers <- length(Tickers) # Check number of tickers
TCount <- as.integer(sum(Securities$df.control$total.obs)/NTickers)
RefDates <- unique(Securities$df.tickers$ref.date) # Unique dates
TRefDates <- Securities$df.tickers$ref.date[1:TCount] # Check
NObservations <- length(RefDates)
CountDiff <- TCount - NObservations # Any duplicate dates ?
# Order of tickers often different
RefTickers <- unique(Securities$df.tickers$ticker)
NRefTickers <- length(RefTickers)
# Ticker order based on data pull
AdjPrices <- data.frame(matrix(vector(), NObservations, NRefTickers, 
  dimnames=list(c(), RefTickers)), stringsAsFactors=F)
AdjPrices$Date <- RefDates
AdjPrices$JDate <- as.integer(RefDates)
k <- 0
for(i in 1:NTickers){
  for(j in 1:(NObservations + CountDiff)){
    k <- k + 1
    if(j==1){
      AdjPrices[j,i] <- Securities$df.tickers$price.adjusted[k]
    }
    else {
      if(Securities$df.tickers$ref.date[k-1] != 
        Securities$df.tickers$ref.date[k]){
        AdjPrices[j,i] <- Securities$df.tickers$price.adjusted[k]
      }
    }
    if(j>1 && is.na(AdjPrices[j,i]))AdjPrices[j,i] <- AdjPrices[j-1,i]
  }
}
# Clean up duplicate dates and NA dates
NObs <- NObservations
for(i in 2:(NObservations + CountDiff)){
  if(AdjPrices$JDate[i-1] == AdjPrices$JDate[i] || is.na(AdjPrices$JDate[i])){
    AdjPrices <- AdjPrices[-c(i), ] 
  }
} 
row.names(AdjPrices) <- as.Date(AdjPrices$JDate)
TDates <- AdjPrices$Date
AdjPricesz <- zoo(AdjPrices, TDates)
AdjPricesz$JDate <- NULL
AdjPricesz$Date <- NULL
AdjPriceszR <- AdjPricesz
AdjPriceszRM1 <- AdjPriceszR[-1,]
for(i in 1:NTickers){
  AdjPriceszRM1[,i] <- diff(log(as.numeric(AdjPricesz[,i])))
}
NT <- data.frame(matrix(vector(), 1, NTickers, dimnames=list(c(), Tickers)), 
  stringsAsFactors=F)
rownames(NT) <- AdjPrices$Date[1]
AdjPricesRet <- as.data.frame(AdjPriceszRM1)
AdjPricesRet <- rbind(NT, AdjPricesRet) # Reorders to original Tickers order
AdjPricesTotRet <- AdjPricesRet
AdjPricesTotRet[1,] <- 1.0
for(i in 1:NTickers){
  for(j in 2:NObservations){
    AdjPricesTotRet[j,i]<-as.numeric(AdjPricesTotRet[j-1,i]) *
      exp(as.numeric(AdjPricesRet[j,i]))
  }
}
AdjPricesTotRet$JDate <- AdjPrices$JDate
MDYDates <- date.mdy(AdjPricesTotRet$JDate, weekday = TRUE)
AdjPricesTotRet$Month <- MDYDates$month
AdjPricesTotRet$Day <- MDYDates$day
AdjPricesTotRet$Year <- MDYDates$year
AdjPricesTotRet$Weekday <- MDYDates$weekday # Saturday = 1, Friday = 7
#
# Only with daily frequency, work on forward fill and other periodicities
#
JDate <- seq(from=StartDate, to=EndDate, by="day")
WDay <- weekdays(seq(from=StartDate, to=EndDate, by="day"))
DateSequence <- as.data.frame(cbind(JDate, WDay))
row.names(DateSequence) <- as.Date(JDate)
LengthDS <- nrow(DateSequence)
DateSequence$RowToKeep <- TRUE
for(i in 1:LengthDS){
  if(DateSequence$WDay[i] == 'Saturday' ||
    DateSequence$WDay[i] == 'Sunday'){
    DateSequence$RowToKeep[i] <- FALSE
  }
}
# Delete Saturday and Sunday
DateSequenceWD <- DateSequence # Data sequence, weekday only
for(i in 1:LengthDS){
  if(i < length(DateSequenceWD$JDate)){
    if(DateSequenceWD$RowToKeep[i] == FALSE){
      DateSequenceWD <- DateSequenceWD[-c(i,i+1),]
    }
  }
}
# Forward fill missing data
if(Frequency=='daily'){ # Number of unique dates
  AdjPricesTotRetWD <- merge(x=DateSequenceWD, y=AdjPricesTotRet, 
    by.x = "JDate", by.y = "JDate", all = TRUE)
  LengthAPTRWD <- length(AdjPricesTotRetWD$JDate)
  for(i in 1:LengthAPTRWD){
    if(is.na(AdjPricesTotRetWD$Weekday[i])){
      for(j in 1:NTickers){
        AdjPricesTotRetWD[i,j+3] <- AdjPricesTotRetWD[i-1,j+3]  
      }
      MDYDates <- date.mdy(AdjPricesTotRet$JDate[i], weekday = TRUE)
      AdjPricesTotRetWD$Month[i] <- MDYDates$month
      AdjPricesTotRetWD$Day[i] <- MDYDates$day
      AdjPricesTotRetWD$Year[i] <- MDYDates$year
      AdjPricesTotRetWD$Weekday[i] <- MDYDates$weekday # Saturday = 1, Friday = 7
    }
  }  
}
#
# House cleaning and reorder columns
#
TempAP <- AdjPricesTotRetWD
TempAP$RowToKeep <- NULL
TempAP$WDay <- NULL
TempAP$Month <- NULL
TempAP$Day <- NULL
TempAP$Year <- NULL
TempAP$Weekday <- NULL
TempAP <- TempAP[c("JDate", Tickers)]
if(PORTFOLIO){
  TempAPP <- TempAP #as.data.frame(TempAP)
  if(PORTSIZE == 1){
    TempAPP['PORT1'] <- 0.0
    TempAPP$PORT1 <- as.numeric(TempAPP[, 3]) 
    TempAPP$PORT1 <- TempAPP$PORT1/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT1")]
    Tickers <- c(Tickers[1], 'PORT1')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 2){
    TempAPP['PORT2'] <- 0.0
    TempAPP$PORT2 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4])
    TempAPP$PORT2 <- TempAPP$PORT2/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT2")]
    Tickers <- c(Tickers[1], 'PORT2')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 3){
    TempAPP['PORT3'] <- 0.0
    TempAPP$PORT3 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + as.numeric(TempAPP[, 5])
    TempAPP$PORT3 <- TempAPP$PORT3/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT3")]
    Tickers <- c(Tickers[1], 'PORT3')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 4){
    TempAPP['PORT4'] <- 0.0
    TempAPP$PORT4 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6]) 
    TempAPP$PORT4 <- TempAPP$PORT4/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT4")]
    Tickers <- c(Tickers[1], 'PORT4')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 5){
    TempAPP['PORT5'] <- 0.0
    TempAPP$PORT5 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6])  + as.numeric(TempAPP[, 7]) 
    TempAPP$PORT5 <- TempAPP$PORT5/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT5")]
    Tickers <- c(Tickers[1], 'PORT5')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 6){
    TempAPP['PORT6'] <- 0.0
    TempAPP$PORT6 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6])  + as.numeric(TempAPP[, 7])  + 
      as.numeric(TempAPP[, 8]) 
    TempAPP$PORT6 <- TempAPP$PORT6/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT6")]
    Tickers <- c(Tickers[1], 'PORT6')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 7){
    TempAPP['PORT7'] <- 0.0
    TempAPP$PORT7 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6])  + as.numeric(TempAPP[, 7])  + 
      as.numeric(TempAPP[, 8]) + as.numeric(TempAPP[, 9]) 
    TempAPP$PORT7 <- TempAPP$PORT7/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT7")]
    Tickers <- c(Tickers[1], 'PORT7')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 8){
    TempAPP['PORT8'] <- 0.0
    TempAPP$PORT8 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6])  + as.numeric(TempAPP[, 7])  + 
      as.numeric(TempAPP[, 8]) + as.numeric(TempAPP[, 9]) + as.numeric(TempAPP[, 10]) 
    TempAPP$PORT8 <- TempAPP$PORT8/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT8")]
    Tickers <- c(Tickers[1], 'PORT8')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 9){
    TempAPP['PORT9'] <- 0.0
    TempAPP$PORT9 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6]) + as.numeric(TempAPP[, 7])  + 
      as.numeric(TempAPP[, 8]) + as.numeric(TempAPP[, 9]) + as.numeric(TempAPP[, 10])  + 
      as.numeric(TempAPP[, 11]) 
    TempAPP$PORT9 <- TempAPP$PORT9/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT9")]
    Tickers <- c(Tickers[1], 'PORT9')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
  if(PORTSIZE == 10){
    TempAPP['PORT10'] <- 0.0
    TempAPP$PORT10 <- as.numeric(TempAPP[, 3]) + as.numeric(TempAPP[, 4]) + 
      as.numeric(TempAPP[, 5]) + as.numeric(TempAPP[, 6]) + as.numeric(TempAPP[, 7])  + 
      as.numeric(TempAPP[, 8]) + as.numeric(TempAPP[, 9]) + as.numeric(TempAPP[, 10])  + 
      as.numeric(TempAPP[, 11]) + as.numeric(TempAPP[, 12]) 
    TempAPP$PORT10 <- TempAPP$PORT10/PORTSIZE
    TempAP <- TempAPP[c("JDate", Tickers[1], "PORT10")]
    Tickers <- c(Tickers[1], 'PORT10')
    RefTickers <- Tickers
    Names <- Tickers
    NTickers <- 2
  }
}
#
# Base zoo object
#
SPz <- zoo(TempAP)  # zoo object same size as SP
LengthSPz <- length(SPz$JDate)
if (Periodicity == 1){
  SP1z <- SPz
} else if (Periodicity == 2) { # Every 2nd trading day
  toDelete <- seq(1, nrow(SPz), 2)
  SP1z <- SPz[toDelete,]
} else if (Periodicity == 3) { # Every 3rd trading day
  toDelete <- seq(1, nrow(SPz), 3)
  SP1z <- SPz[toDelete,]
} else if (Periodicity == 4) { # Every 4th trading day
  toDelete <- seq(1, nrow(SPz), 4)
  SP1z <- SPz[toDelete,]
} else if (Periodicity == 5) { # Every 5th trading day
  toDelete <- seq(1, nrow(SPz), 5)
  SP1z <- SPz[toDelete,]
} else if (Periodicity == 6) { # Weekly
  TDz <- as.Date(as.integer(SPz$JDate))
  WeekDay <- weekdays(TDz)
  j <- 0
  Index <- c(1:LengthSPz)
  for (i in 1:LengthSPz){
    Index[i] <- 0
    if(WeekDay[i] == DayOfWeek){
      j = j + 1
      Index[j] = i
    }
  }
  toDelete <- Index
  SP1z <- SPz[toDelete,]
} else if (Periodicity == 7) { # Monthly
  # TDz <- SPz$Date1
  TDz <- as.Date(as.integer(SPz$JDate))
  # TDate <- as.character(SPz$Date1)
  # TDate <- as.Date(TDate)
  Month <- months(TDz) #months(TDate)
  j <- 0
  Index <- c(1:LengthSPz)
  Index[1] <- 0
  for (i in 2:LengthSPz){
    Index[i] <- 0
    if(Month[i] != Month[i-1]){
      j = j + 1
      k = i + MonthAdjust
      if(k < LengthSPz) Index[j] = k
    }
  }
  toDelete <- Index
  SP1z <- SPz[toDelete,]
}
# RefDates <- unique(Securities$df.tickers$ref.date) # Unique dates
# RefDates1 <- format.Date(as.date(as.numeric(SPz$JDate)+3654), "%Y-%m-%d")
SP1z <- SP1z[complete.cases(SP1z),] # Remove missing data
LengthSP1z = length(SP1z$JDate)
index(SP1z) <- 1:LengthSP1z # Change zoo index
SPz <- SP1z
# SPz$Date <- format.Date(as.date(as.numeric(SPz$JDate)+3654), "%Y-%m-%d")
# head(SPz)
# Compute CC Returns
A = 0 # Need to append one due to loss of one in calculating returns
for(i in 1:NTickers){
  Tempz = diff(log(as.numeric(SPz[,i+1])))
  Tempz1 <- zoo(append(Tempz, A, after = 0))
  SPz$TempR <- Tempz1
  names(SPz)[names(SPz)=="TempR"] <- paste0(Tickers[i], "R")
}
#
# Rolling statistical parameters (EWMA)
#
Weights = as.numeric(c(1:RollingWindow)) # Exponentially weighted moving average
Sum = 0.0
for(i in 1:RollingWindow){
  Weights[i] <- 100*(1 - Lambda)*Lambda^(i-1)/(1 - Lambda^(RollingWindow))
  Sum = Sum + Weights[i]
}
# Apply heaviest weight to recent observation (closer to present, end of data)
Weights <- sort(Weights, decreasing = FALSE) 
# Check rationality of weighting scheme
# Weights
# SumW <- sum(Weights)
# SumW
A <- rep(NA, RollingWindow - 1)
# Rolling weighted means
for(i in 1:NTickers){
  Tempz <- rollapply(as.numeric(SPz[,NTickers+1+i]), RollingWindow, 
    function(x, wt)(wtd.mean(x, wt)), Weights, align = "right")
  # function(x, wt)(wtd.mean(x, wt)), Weights, align = "right")
Tempz <- zoo(append(Tempz, A, after = 0))
  SPz$TempR <- Tempz
  names(SPz)[names(SPz)=="TempR"] <- paste0(Tickers[i], "MNM")
}
# Rolling weighted standard deviations
for(i in 1:NTickers){
  Tempz <- rollapply(as.numeric(SPz[,NTickers+1+i]), RollingWindow, 
    function(x, wt)(sqrt(wtd.var(x, wt))), Weights, align = "right")
  # function(x, wt)(sqrt(wtd.var(x, wt))), Weights, align = "right")
Tempz <- zoo(append(Tempz, A, after = 0))
  SPz$TempR <- Tempz
  names(SPz)[names(SPz)=="TempR"] <- paste0(Tickers[i], "SDM")
}
#
# Work on Volatility Benefit
#
ColLength <- length(SPz[,1])
RowLength <- length(SPz[1,])
NTickersP3 <- as.integer(NTickers+3)
ListDF <- c('JDate', Tickers, 'EWSD', 'VB')
VolBen <- data.frame(matrix(vector(), ColLength, NTickersP3, 
  dimnames=list(c(), ListDF)), stringsAsFactors=F)
VolBen[,1] <- as.integer(SPz[,1])
for(i in 1:NTickers){
  VolBen[,i+1] <- as.numeric(SPz[,RowLength - NTickers + i])
}
for(j in 1:ColLength){
  tVB <- 0
  for(i in 2:NTickers){
    tVB <- tVB + VolBen[j,i+1]   
  }
  VolBen[j,NTickersP3-1] <- tVB/(NTickers - 1)
  VolBen[j,NTickersP3] <- (1 - VolBen[j,2]/VolBen[j,NTickersP3-1])*100
}
#
# Rolling weighted correlations and betas with first instrument (SPY)
#  
LengthSPz <- length(SPz$JDate)
LengthCorr = LengthSPz - RollingWindow + 1
x <- as.numeric(array(1:RollingWindow))
y <- as.numeric(array(1:RollingWindow))
SCorr = LengthCorr*NTickers
CorrM <- as.numeric(array(data = NA, dim = SCorr))
# 
# LengthCorr
# NTickers
# SCorr
# head(CorrM)
# RefTickers
# 
CorrM <- matrix(CorrM, nrow=LengthCorr, ncol=NTickers, 
  dimnames = list(1:LengthCorr,RefTickers))
BetaM <- as.numeric(array(data = NA, dim = SCorr))
BetaM <- matrix(BetaM, nrow=LengthCorr, ncol=NTickers, 
  dimnames = list(1:LengthCorr,RefTickers))
for(k in 1:NTickers){
  for(j in 1:LengthCorr){
    for(i in 1:RollingWindow){
      x[i] <- as.numeric(SPz[i + j - 1, NTickers + 1 + k])
      y[i] <- as.numeric(SPz[i + j - 1, NTickers + 2])
    }
    if(sd(x) == 0 || sd(y) == 0){
      CorrM[j,k] <- 0
      BetaM[j,k] <- 0
    } else {
      z1 <- wtd.cor(x, y, Weights)
      zx <- sqrt(wtd.var(x=x, weights = Weights, normwt = TRUE))
      zy <- sqrt(wtd.var(x=y, weights = Weights, normwt = TRUE))
      CorrM[j,k] <- z1[1]
      BetaM[j,k] <- z1[1]*zx/zy
    }
  }
  Tempz <- zoo(append(CorrM[,k], A, after = 0))
  SPz$TempR <- Tempz
  names(SPz)[names(SPz)=="TempR"] <- paste0(Tickers[k], "Cor")
  Tempz <- zoo(append(BetaM[,k], A, after = 0))
  SPz$TempR <- Tempz
  names(SPz)[names(SPz)=="TempR"] <- paste0(Tickers[k], "Beta")
}


tail(SPz)
