# KM Base Rate Static Risk Measures.R
# Base rate static risk measures
L <- InitialCurves$Base[2]
k1 <- InitialCurves$Base[3]
S <- InitialCurves$Base[4]
C1 <- InitialCurves$Base[5]
k2 <- InitialCurves$Base[6]
C2 <- InitialCurves$Base[7]
k3 <- InitialCurves$Base[8]
C3 <- InitialCurves$Base[9]
k4 <- InitialCurves$Base[10]
C4 <- InitialCurves$Base[11]
k5 <- InitialCurves$Base[12]
C5 <- InitialCurves$Base[13]
# Base rate maturity coefficients at Horizon
M <- dfStaticRiskMeasures$Maturity-Horizon
LengthM = length(M)
for(i in 1:LengthM){ # Cannot have zero in LSC model
  if(M[i] == 0)M[i] <- 0.000001
}
x1 <- (k1/M)*(1.0 - exp(-M/k1))
x2 <- x1 - exp(-M/k1)
x3 <- (k2/M) * (1.0 - exp(-M/k2)) - exp(-M/k2)
x4 <- (k3/M) * (1.0 - exp(-M/k3)) - exp(-M/k3)
x5 <- (k4/M) * (1.0 - exp(-M/k4)) - exp(-M/k4)
x6 <- (k5/M) * (1.0 - exp(-M/k5)) - exp(-M/k5)
W <- dfStaticRiskMeasures$Weight # Weight of instrument cash flow
CW <- dfStaticRiskMeasures$WBase # Weight of particular curve
#
# Base Duration
#
dfStaticRiskMeasures$BaseDurationLevel <- M * 1.0 * W * CW
dfStaticRiskMeasures$BaseDurationSlope <- M * x1 * W * CW
dfStaticRiskMeasures$BaseDurationCurve1 <- M * x2 * W * CW
dfStaticRiskMeasures$BaseDurationCurve2 <- M * x3 * W * CW
dfStaticRiskMeasures$BaseDurationCurve3 <- M * x4 * W * CW
dfStaticRiskMeasures$BaseDurationCurve4 <- M * x5 * W * CW
dfStaticRiskMeasures$BaseDurationCurve5 <- M * x6 * W * CW
# Level
dfBaseDurationLevel <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationLevel))
dfBaseDurationLevel$BaseDurationLevel <- dfBaseDurationLevel$dfStaticRiskMeasures
dfBaseDurationLevel$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationLevel <- rbind(dfBaseDurationLevel, y = c(MaxInstruments+1, NA))
dfBaseDurationLevel <- rbind(dfBaseDurationLevel, y = c(MaxInstruments+2, NA))
dfBaseDurationLevel <- rbind(dfBaseDurationLevel, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0 # Static risk measure for assets
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationLevel$BaseDurationLevel[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0 # Static risk measure for assets
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationLevel$BaseDurationLevel[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationLevel$BaseDurationLevel[MaxInstruments+1] <- NA
} else {
  dfBaseDurationLevel$BaseDurationLevel[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationLevel$BaseDurationLevel[MaxInstruments+2] <- SRMA
dfBaseDurationLevel$BaseDurationLevel[MaxInstruments+3] <- SRML
# Slope
dfBaseDurationSlope <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationSlope))
dfBaseDurationSlope$BaseDurationSlope <- dfBaseDurationSlope$dfStaticRiskMeasures
dfBaseDurationSlope$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationSlope <- rbind(dfBaseDurationSlope, y = c(MaxInstruments+1, NA))
dfBaseDurationSlope <- rbind(dfBaseDurationSlope, y = c(MaxInstruments+2, NA))
dfBaseDurationSlope <- rbind(dfBaseDurationSlope, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationSlope$BaseDurationSlope[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationSlope$BaseDurationSlope[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationSlope$BaseDurationSlope[MaxInstruments+1] <- NA
} else {
  dfBaseDurationSlope$BaseDurationSlope[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationSlope$BaseDurationSlope[MaxInstruments+2] <- SRMA
dfBaseDurationSlope$BaseDurationSlope[MaxInstruments+3] <- SRML
# Curvature 1
dfBaseDurationCurve1 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationCurve1))
dfBaseDurationCurve1$BaseDurationCurve1 <- dfBaseDurationCurve1$dfStaticRiskMeasures
dfBaseDurationCurve1$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationCurve1 <- rbind(dfBaseDurationCurve1, y = c(MaxInstruments+1, NA))
dfBaseDurationCurve1 <- rbind(dfBaseDurationCurve1, y = c(MaxInstruments+2, NA))
dfBaseDurationCurve1 <- rbind(dfBaseDurationCurve1, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationCurve1$BaseDurationCurve1[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationCurve1$BaseDurationCurve1[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationCurve1$BaseDurationCurve1[MaxInstruments+1] <- NA
} else {
  dfBaseDurationCurve1$BaseDurationCurve1[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationCurve1$BaseDurationCurve1[MaxInstruments+2] <- SRMA
dfBaseDurationCurve1$BaseDurationCurve1[MaxInstruments+3] <- SRML
# Curvature 2
dfBaseDurationCurve2 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationCurve2))
dfBaseDurationCurve2$BaseDurationCurve2 <- dfBaseDurationCurve2$dfStaticRiskMeasures
dfBaseDurationCurve2$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationCurve2 <- rbind(dfBaseDurationCurve2, y = c(MaxInstruments+1, NA))
dfBaseDurationCurve2 <- rbind(dfBaseDurationCurve2, y = c(MaxInstruments+2, NA))
dfBaseDurationCurve2 <- rbind(dfBaseDurationCurve2, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationCurve2$BaseDurationCurve2[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationCurve2$BaseDurationCurve2[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationCurve2$BaseDurationCurve2[MaxInstruments+1] <- NA
} else {
  dfBaseDurationCurve2$BaseDurationCurve2[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationCurve2$BaseDurationCurve2[MaxInstruments+2] <- SRMA
dfBaseDurationCurve2$BaseDurationCurve2[MaxInstruments+3] <- SRML
# Curvature 3
dfBaseDurationCurve3 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationCurve3))
dfBaseDurationCurve3$BaseDurationCurve3 <- dfBaseDurationCurve3$dfStaticRiskMeasures
dfBaseDurationCurve3$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationCurve3 <- rbind(dfBaseDurationCurve3, y = c(MaxInstruments+1, NA))
dfBaseDurationCurve3 <- rbind(dfBaseDurationCurve3, y = c(MaxInstruments+2, NA))
dfBaseDurationCurve3 <- rbind(dfBaseDurationCurve3, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationCurve3$BaseDurationCurve3[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationCurve3$BaseDurationCurve3[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationCurve3$BaseDurationCurve3[MaxInstruments+1] <- NA
} else {
  dfBaseDurationCurve3$BaseDurationCurve3[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationCurve3$BaseDurationCurve3[MaxInstruments+2] <- SRMA
dfBaseDurationCurve3$BaseDurationCurve3[MaxInstruments+3] <- SRML
# Curvature 4
dfBaseDurationCurve4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationCurve4))
dfBaseDurationCurve4$BaseDurationCurve4 <- dfBaseDurationCurve4$dfStaticRiskMeasures
dfBaseDurationCurve4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationCurve4 <- rbind(dfBaseDurationCurve4, y = c(MaxInstruments+1, NA))
dfBaseDurationCurve4 <- rbind(dfBaseDurationCurve4, y = c(MaxInstruments+2, NA))
dfBaseDurationCurve4 <- rbind(dfBaseDurationCurve4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationCurve4$BaseDurationCurve4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationCurve4$BaseDurationCurve4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationCurve4$BaseDurationCurve4[MaxInstruments+1] <- NA
} else {
  dfBaseDurationCurve4$BaseDurationCurve4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationCurve4$BaseDurationCurve4[MaxInstruments+2] <- SRMA
dfBaseDurationCurve4$BaseDurationCurve4[MaxInstruments+3] <- SRML
# Curvature 5
dfBaseDurationCurve5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseDurationCurve5))
dfBaseDurationCurve5$BaseDurationCurve5 <- dfBaseDurationCurve5$dfStaticRiskMeasures
dfBaseDurationCurve5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseDurationCurve5 <- rbind(dfBaseDurationCurve5, y = c(MaxInstruments+1, NA))
dfBaseDurationCurve5 <- rbind(dfBaseDurationCurve5, y = c(MaxInstruments+2, NA))
dfBaseDurationCurve5 <- rbind(dfBaseDurationCurve5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseDurationCurve5$BaseDurationCurve5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseDurationCurve5$BaseDurationCurve5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseDurationCurve5$BaseDurationCurve5[MaxInstruments+1] <- NA
} else {
  dfBaseDurationCurve5$BaseDurationCurve5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseDurationCurve5$BaseDurationCurve5[MaxInstruments+2] <- SRMA
dfBaseDurationCurve5$BaseDurationCurve5[MaxInstruments+3] <- SRML
#
# Base Convexity
#
dfStaticRiskMeasures$BaseConvexityLevel <- (M^2) * 1.0 * W * CW
dfStaticRiskMeasures$BaseConvexitySlope <- (M^2) * (x1^2) * W * CW
dfStaticRiskMeasures$BaseConvexityCurve1 <- (M^2) * (x2^2) * W * CW
dfStaticRiskMeasures$BaseConvexityCurve2 <- (M^2) * (x3^2) * W * CW
dfStaticRiskMeasures$BaseConvexityCurve3 <- (M^2) * (x4^2) * W * CW
dfStaticRiskMeasures$BaseConvexityCurve4 <- (M^2) * (x5^2) * W * CW
dfStaticRiskMeasures$BaseConvexityCurve5 <- (M^2) * (x6^2) * W * CW
# Level
dfBaseConvexityLevel <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexityLevel))
dfBaseConvexityLevel$BaseConvexityLevel <- dfBaseConvexityLevel$dfStaticRiskMeasures
dfBaseConvexityLevel$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexityLevel <- rbind(dfBaseConvexityLevel, y = c(MaxInstruments+1, NA))
dfBaseConvexityLevel <- rbind(dfBaseConvexityLevel, y = c(MaxInstruments+2, NA))
dfBaseConvexityLevel <- rbind(dfBaseConvexityLevel, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexityLevel$BaseConvexityLevel[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexityLevel$BaseConvexityLevel[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexityLevel$BaseConvexityLevel[MaxInstruments+1] <- NA
} else {
  dfBaseConvexityLevel$BaseConvexityLevel[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexityLevel$BaseConvexityLevel[MaxInstruments+2] <- SRMA
dfBaseConvexityLevel$BaseConvexityLevel[MaxInstruments+3] <- SRML
# Slope
dfBaseConvexitySlope <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexitySlope))
dfBaseConvexitySlope$BaseConvexitySlope <- dfBaseConvexitySlope$dfStaticRiskMeasures
dfBaseConvexitySlope$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexitySlope <- rbind(dfBaseConvexitySlope, y = c(MaxInstruments+1, NA))
dfBaseConvexitySlope <- rbind(dfBaseConvexitySlope, y = c(MaxInstruments+2, NA))
dfBaseConvexitySlope <- rbind(dfBaseConvexitySlope, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexitySlope$BaseConvexitySlope[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexitySlope$BaseConvexitySlope[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexitySlope$BaseConvexitySlope[MaxInstruments+1] <- NA
} else {
  dfBaseConvexitySlope$BaseConvexitySlope[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexitySlope$BaseConvexitySlope[MaxInstruments+2] <- SRMA
dfBaseConvexitySlope$BaseConvexitySlope[MaxInstruments+3] <- SRML
# Curvature 1
dfBaseConvexityCurve1 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexityCurve1))
dfBaseConvexityCurve1$BaseConvexityCurve1 <- dfBaseConvexityCurve1$dfStaticRiskMeasures
dfBaseConvexityCurve1$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexityCurve1 <- rbind(dfBaseConvexityCurve1, y = c(MaxInstruments+1, NA))
dfBaseConvexityCurve1 <- rbind(dfBaseConvexityCurve1, y = c(MaxInstruments+2, NA))
dfBaseConvexityCurve1 <- rbind(dfBaseConvexityCurve1, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexityCurve1$BaseConvexityCurve1[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexityCurve1$BaseConvexityCurve1[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexityCurve1$BaseConvexityCurve1[MaxInstruments+1] <- NA
} else {
  dfBaseConvexityCurve1$BaseConvexityCurve1[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexityCurve1$BaseConvexityCurve1[MaxInstruments+2] <- SRMA
dfBaseConvexityCurve1$BaseConvexityCurve1[MaxInstruments+3] <- SRML
dfBaseConvexityCurve1
# Curvature 2
dfBaseConvexityCurve2 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexityCurve2))
dfBaseConvexityCurve2$BaseConvexityCurve2 <- dfBaseConvexityCurve2$dfStaticRiskMeasures
dfBaseConvexityCurve2$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexityCurve2 <- rbind(dfBaseConvexityCurve2, y = c(MaxInstruments+1, NA))
dfBaseConvexityCurve2 <- rbind(dfBaseConvexityCurve2, y = c(MaxInstruments+2, NA))
dfBaseConvexityCurve2 <- rbind(dfBaseConvexityCurve2, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexityCurve2$BaseConvexityCurve2[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexityCurve2$BaseConvexityCurve2[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexityCurve2$BaseConvexityCurve2[MaxInstruments+1] <- NA
} else {
  dfBaseConvexityCurve2$BaseConvexityCurve2[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexityCurve2$BaseConvexityCurve2[MaxInstruments+2] <- SRMA
dfBaseConvexityCurve2$BaseConvexityCurve2[MaxInstruments+3] <- SRML
# Curvature 3
dfBaseConvexityCurve3 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexityCurve3))
dfBaseConvexityCurve3$BaseConvexityCurve3 <- dfBaseConvexityCurve3$dfStaticRiskMeasures
dfBaseConvexityCurve3$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexityCurve3 <- rbind(dfBaseConvexityCurve3, y = c(MaxInstruments+1, NA))
dfBaseConvexityCurve3 <- rbind(dfBaseConvexityCurve3, y = c(MaxInstruments+2, NA))
dfBaseConvexityCurve3 <- rbind(dfBaseConvexityCurve3, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexityCurve3$BaseConvexityCurve3[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexityCurve3$BaseConvexityCurve3[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexityCurve3$BaseConvexityCurve3[MaxInstruments+1] <- NA
} else {
  dfBaseConvexityCurve3$BaseConvexityCurve3[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexityCurve3$BaseConvexityCurve3[MaxInstruments+2] <- SRMA
dfBaseConvexityCurve3$BaseConvexityCurve3[MaxInstruments+3] <- SRML
# Curvature 4
dfBaseConvexityCurve4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexityCurve4))
dfBaseConvexityCurve4$BaseConvexityCurve4 <- dfBaseConvexityCurve4$dfStaticRiskMeasures
dfBaseConvexityCurve4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexityCurve4 <- rbind(dfBaseConvexityCurve4, y = c(MaxInstruments+1, NA))
dfBaseConvexityCurve4 <- rbind(dfBaseConvexityCurve4, y = c(MaxInstruments+2, NA))
dfBaseConvexityCurve4 <- rbind(dfBaseConvexityCurve4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexityCurve4$BaseConvexityCurve4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexityCurve4$BaseConvexityCurve4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexityCurve4$BaseConvexityCurve4[MaxInstruments+1] <- NA
} else {
  dfBaseConvexityCurve4$BaseConvexityCurve4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexityCurve4$BaseConvexityCurve4[MaxInstruments+2] <- SRMA
dfBaseConvexityCurve4$BaseConvexityCurve4[MaxInstruments+3] <- SRML
# Curvature 5
dfBaseConvexityCurve5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseConvexityCurve5))
dfBaseConvexityCurve5$BaseConvexityCurve5 <- dfBaseConvexityCurve5$dfStaticRiskMeasures
dfBaseConvexityCurve5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseConvexityCurve5 <- rbind(dfBaseConvexityCurve5, y = c(MaxInstruments+1, NA))
dfBaseConvexityCurve5 <- rbind(dfBaseConvexityCurve5, y = c(MaxInstruments+2, NA))
dfBaseConvexityCurve5 <- rbind(dfBaseConvexityCurve5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseConvexityCurve5$BaseConvexityCurve5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseConvexityCurve5$BaseConvexityCurve5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseConvexityCurve5$BaseConvexityCurve5[MaxInstruments+1] <- NA
} else {
  dfBaseConvexityCurve5$BaseConvexityCurve5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseConvexityCurve5$BaseConvexityCurve5[MaxInstruments+2] <- SRMA
dfBaseConvexityCurve5$BaseConvexityCurve5[MaxInstruments+3] <- SRML
#
# Base Cross Convexiities (19!)
#
# Level x _____
dfStaticRiskMeasures$BaseCrossConvexityCCLS <- (M^2) * 1.0 * x1 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCLC1 <- (M^2) * 1.0 * x2 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCLC2 <- (M^2) * 1.0 * x3 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCLC3 <- (M^2) * 1.0 * x4 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCLC4 <- (M^2) * 1.0 * x5 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCLC5 <- (M^2) * 1.0 * x6 * W * CW
# Slope x _____
dfStaticRiskMeasures$BaseCrossConvexityCCSC1 <- (M^2) * x1 * x2 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCSC2 <- (M^2) * x1 * x3 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCSC3 <- (M^2) * x1 * x4 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCSC4 <- (M^2) * x1 * x5 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCSC5 <- (M^2) * x1 * x6 * W * CW
# Curve1 x _____
dfStaticRiskMeasures$BaseCrossConvexityCCC1C2 <- (M^2) * x2 * x3 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCC1C3 <- (M^2) * x2 * x4 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCC1C4 <- (M^2) * x2 * x5 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCC1C5 <- (M^2) * x2 * x6 * W * CW
# Curve2 x _____
dfStaticRiskMeasures$BaseCrossConvexityCCC2C3 <- (M^2) * x3 * x4 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCC2C4 <- (M^2) * x3 * x5 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCC2C5 <- (M^2) * x3 * x6 * W * CW
# Curve4 x _____
dfStaticRiskMeasures$BaseCrossConvexityCCC3C4 <- (M^2) * x4 * x5 * W * CW
dfStaticRiskMeasures$BaseCrossConvexityCCC3C5 <- (M^2) * x4 * x6 * W * CW
# Curve5 x _____
dfStaticRiskMeasures$BaseCrossConvexityCCC4C5 <- (M^2) * x5 * x6 * W * CW
# Level x Slope (CCLS)
dfBaseCrossConvexityCCLS <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCLS))
dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS <- dfBaseCrossConvexityCCLS$dfStaticRiskMeasures
dfBaseCrossConvexityCCLS$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCLS <- rbind(dfBaseCrossConvexityCCLS, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCLS <- rbind(dfBaseCrossConvexityCCLS, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCLS <- rbind(dfBaseCrossConvexityCCLS, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCLS$BaseCrossConvexityCCLS[MaxInstruments+3] <- SRML
# Level x Curve1 (CCLC1)
dfBaseCrossConvexityCCLC1 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCLC1))
dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1 <- dfBaseCrossConvexityCCLC1$dfStaticRiskMeasures
dfBaseCrossConvexityCCLC1$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCLC1 <- rbind(dfBaseCrossConvexityCCLC1, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCLC1 <- rbind(dfBaseCrossConvexityCCLC1, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCLC1 <- rbind(dfBaseCrossConvexityCCLC1, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCLC1$BaseCrossConvexityCCLC1[MaxInstruments+3] <- SRML
# Level x Curve2 (CCLC2)
dfBaseCrossConvexityCCLC2 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCLC2))
dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2 <- dfBaseCrossConvexityCCLC2$dfStaticRiskMeasures
dfBaseCrossConvexityCCLC2$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCLC2 <- rbind(dfBaseCrossConvexityCCLC2, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCLC2 <- rbind(dfBaseCrossConvexityCCLC2, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCLC2 <- rbind(dfBaseCrossConvexityCCLC2, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCLC2$BaseCrossConvexityCCLC2[MaxInstruments+3] <- SRML
# Level x Curve3 (CCLC3)
dfBaseCrossConvexityCCLC3 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCLC3))
dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3 <- dfBaseCrossConvexityCCLC3$dfStaticRiskMeasures
dfBaseCrossConvexityCCLC3$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCLC3 <- rbind(dfBaseCrossConvexityCCLC3, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCLC3 <- rbind(dfBaseCrossConvexityCCLC3, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCLC3 <- rbind(dfBaseCrossConvexityCCLC3, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCLC3$BaseCrossConvexityCCLC3[MaxInstruments+3] <- SRML
# Level x Curve4 (CCLC4)
dfBaseCrossConvexityCCLC4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCLC4))
dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4 <- dfBaseCrossConvexityCCLC4$dfStaticRiskMeasures
dfBaseCrossConvexityCCLC4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCLC4 <- rbind(dfBaseCrossConvexityCCLC4, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCLC4 <- rbind(dfBaseCrossConvexityCCLC4, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCLC4 <- rbind(dfBaseCrossConvexityCCLC4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCLC4$BaseCrossConvexityCCLC4[MaxInstruments+3] <- SRML
# Level x Curve5 (CCLC5)
dfBaseCrossConvexityCCLC5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCLC5))
dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5 <- dfBaseCrossConvexityCCLC5$dfStaticRiskMeasures
dfBaseCrossConvexityCCLC5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCLC5 <- rbind(dfBaseCrossConvexityCCLC5, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCLC5 <- rbind(dfBaseCrossConvexityCCLC5, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCLC5 <- rbind(dfBaseCrossConvexityCCLC5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCLC5$BaseCrossConvexityCCLC5[MaxInstruments+3] <- SRML
# Slope x Curve1 (CCSC1)
dfBaseCrossConvexityCCSC1 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCSC1))
dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1 <- dfBaseCrossConvexityCCSC1$dfStaticRiskMeasures
dfBaseCrossConvexityCCSC1$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCSC1 <- rbind(dfBaseCrossConvexityCCSC1, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCSC1 <- rbind(dfBaseCrossConvexityCCSC1, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCSC1 <- rbind(dfBaseCrossConvexityCCSC1, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCSC1$BaseCrossConvexityCCSC1[MaxInstruments+3] <- SRML
# Level x Curve2 (CCSC2)
dfBaseCrossConvexityCCSC2 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCSC2))
dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2 <- dfBaseCrossConvexityCCSC2$dfStaticRiskMeasures
dfBaseCrossConvexityCCSC2$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCSC2 <- rbind(dfBaseCrossConvexityCCSC2, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCSC2 <- rbind(dfBaseCrossConvexityCCSC2, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCSC2 <- rbind(dfBaseCrossConvexityCCSC2, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCSC2$BaseCrossConvexityCCSC2[MaxInstruments+3] <- SRML
# Level x Curve3 (CCSC3)
dfBaseCrossConvexityCCSC3 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCSC3))
dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3 <- dfBaseCrossConvexityCCSC3$dfStaticRiskMeasures
dfBaseCrossConvexityCCSC3$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCSC3 <- rbind(dfBaseCrossConvexityCCSC3, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCSC3 <- rbind(dfBaseCrossConvexityCCSC3, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCSC3 <- rbind(dfBaseCrossConvexityCCSC3, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCSC3$BaseCrossConvexityCCSC3[MaxInstruments+3] <- SRML
# Level x Curve4 (CCSC4)
dfBaseCrossConvexityCCSC4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCSC4))
dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4 <- dfBaseCrossConvexityCCSC4$dfStaticRiskMeasures
dfBaseCrossConvexityCCSC4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCSC4 <- rbind(dfBaseCrossConvexityCCSC4, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCSC4 <- rbind(dfBaseCrossConvexityCCSC4, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCSC4 <- rbind(dfBaseCrossConvexityCCSC4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCSC4$BaseCrossConvexityCCSC4[MaxInstruments+3] <- SRML
# Level x Curve5 (CCSC5)
dfBaseCrossConvexityCCSC5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCSC5))
dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5 <- dfBaseCrossConvexityCCSC5$dfStaticRiskMeasures
dfBaseCrossConvexityCCSC5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCSC5 <- rbind(dfBaseCrossConvexityCCSC5, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCSC5 <- rbind(dfBaseCrossConvexityCCSC5, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCSC5 <- rbind(dfBaseCrossConvexityCCSC5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCSC5$BaseCrossConvexityCCSC5[MaxInstruments+3] <- SRML
# Curve1 x Curve2 (CCC1C2)
dfBaseCrossConvexityCCC1C2 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC1C2))
dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2 <- dfBaseCrossConvexityCCC1C2$dfStaticRiskMeasures
dfBaseCrossConvexityCCC1C2$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC1C2 <- rbind(dfBaseCrossConvexityCCC1C2, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC1C2 <- rbind(dfBaseCrossConvexityCCC1C2, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC1C2 <- rbind(dfBaseCrossConvexityCCC1C2, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC1C2$BaseCrossConvexityCCC1C2[MaxInstruments+3] <- SRML
# Level x Curve3 (CCC1C3)
dfBaseCrossConvexityCCC1C3 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC1C3))
dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3 <- dfBaseCrossConvexityCCC1C3$dfStaticRiskMeasures
dfBaseCrossConvexityCCC1C3$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC1C3 <- rbind(dfBaseCrossConvexityCCC1C3, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC1C3 <- rbind(dfBaseCrossConvexityCCC1C3, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC1C3 <- rbind(dfBaseCrossConvexityCCC1C3, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC1C3$BaseCrossConvexityCCC1C3[MaxInstruments+3] <- SRML
# Level x Curve4 (CCC1C4)
dfBaseCrossConvexityCCC1C4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC1C4))
dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4 <- dfBaseCrossConvexityCCC1C4$dfStaticRiskMeasures
dfBaseCrossConvexityCCC1C4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC1C4 <- rbind(dfBaseCrossConvexityCCC1C4, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC1C4 <- rbind(dfBaseCrossConvexityCCC1C4, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC1C4 <- rbind(dfBaseCrossConvexityCCC1C4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC1C4$BaseCrossConvexityCCC1C4[MaxInstruments+3] <- SRML
# Level x Curve5 (CCC1C5)
dfBaseCrossConvexityCCC1C5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC1C5))
dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5 <- dfBaseCrossConvexityCCC1C5$dfStaticRiskMeasures
dfBaseCrossConvexityCCC1C5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC1C5 <- rbind(dfBaseCrossConvexityCCC1C5, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC1C5 <- rbind(dfBaseCrossConvexityCCC1C5, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC1C5 <- rbind(dfBaseCrossConvexityCCC1C5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC1C5$BaseCrossConvexityCCC1C5[MaxInstruments+3] <- SRML
# Curve2 x Curve3 (CCC2C3)
dfBaseCrossConvexityCCC2C3 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC2C3))
dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3 <- dfBaseCrossConvexityCCC2C3$dfStaticRiskMeasures
dfBaseCrossConvexityCCC2C3$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC2C3 <- rbind(dfBaseCrossConvexityCCC2C3, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC2C3 <- rbind(dfBaseCrossConvexityCCC2C3, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC2C3 <- rbind(dfBaseCrossConvexityCCC2C3, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC2C3$BaseCrossConvexityCCC2C3[MaxInstruments+3] <- SRML
# _____ x Curve4 (CCC2C4)
dfBaseCrossConvexityCCC2C4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC2C4))
dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4 <- dfBaseCrossConvexityCCC2C4$dfStaticRiskMeasures
dfBaseCrossConvexityCCC2C4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC2C4 <- rbind(dfBaseCrossConvexityCCC2C4, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC2C4 <- rbind(dfBaseCrossConvexityCCC2C4, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC2C4 <- rbind(dfBaseCrossConvexityCCC2C4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC2C4$BaseCrossConvexityCCC2C4[MaxInstruments+3] <- SRML
# _____ x Curve5 (CCC2C5)
dfBaseCrossConvexityCCC2C5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC2C5))
dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5 <- dfBaseCrossConvexityCCC2C5$dfStaticRiskMeasures
dfBaseCrossConvexityCCC2C5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC2C5 <- rbind(dfBaseCrossConvexityCCC2C5, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC2C5 <- rbind(dfBaseCrossConvexityCCC2C5, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC2C5 <- rbind(dfBaseCrossConvexityCCC2C5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC2C5$BaseCrossConvexityCCC2C5[MaxInstruments+3] <- SRML
# Curve3 x Curve4 (CCC3C4)
dfBaseCrossConvexityCCC3C4 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC3C4))
dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4 <- dfBaseCrossConvexityCCC3C4$dfStaticRiskMeasures
dfBaseCrossConvexityCCC3C4$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC3C4 <- rbind(dfBaseCrossConvexityCCC3C4, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC3C4 <- rbind(dfBaseCrossConvexityCCC3C4, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC3C4 <- rbind(dfBaseCrossConvexityCCC3C4, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC3C4$BaseCrossConvexityCCC3C4[MaxInstruments+3] <- SRML
# _____ x Curve5 (CCC3C5)
dfBaseCrossConvexityCCC3C5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC3C5))
dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5 <- dfBaseCrossConvexityCCC3C5$dfStaticRiskMeasures
dfBaseCrossConvexityCCC3C5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC3C5 <- rbind(dfBaseCrossConvexityCCC3C5, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC3C5 <- rbind(dfBaseCrossConvexityCCC3C5, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC3C5 <- rbind(dfBaseCrossConvexityCCC3C5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC3C5$BaseCrossConvexityCCC3C5[MaxInstruments+3] <- SRML
# Curve4 x Curve5 (CCC4C5)
dfBaseCrossConvexityCCC4C5 <- ddply(dfStaticRiskMeasures, .(Instrument), summarize, 
  dfStaticRiskMeasures=sum(BaseCrossConvexityCCC4C5))
dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5 <- dfBaseCrossConvexityCCC4C5$dfStaticRiskMeasures
dfBaseCrossConvexityCCC4C5$dfStaticRiskMeasures <- NULL
# Compute Static Risk Measure for Net Worth
dfBaseCrossConvexityCCC4C5 <- rbind(dfBaseCrossConvexityCCC4C5, y = c(MaxInstruments+1, NA))
dfBaseCrossConvexityCCC4C5 <- rbind(dfBaseCrossConvexityCCC4C5, y = c(MaxInstruments+2, NA))
dfBaseCrossConvexityCCC4C5 <- rbind(dfBaseCrossConvexityCCC4C5, y = c(MaxInstruments+3, NA))
TA <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2]
TL <- dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3]
SRMA <- 0.0
for(i in 1:NumberOfAssets){
  SRMA <- SRMA + dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5[i] * (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i]/TA)
}
SRML <- 0.0
for(i in 1:NumberOfLiabilities){
  SRML <- SRML + dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5[NumberOfAssets+i] * 
    (dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i]/TL)
}
if(TA == -TL){
  dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5[MaxInstruments+1] <- NA
} else {
  dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5[MaxInstruments+1] <- (SRMA*TA + SRML*TL)/(TA + TL)
}
dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5[MaxInstruments+2] <- SRMA
dfBaseCrossConvexityCCC4C5$BaseCrossConvexityCCC4C5[MaxInstruments+3] <- SRML
