# KM Static Calculations.R
#
# Discount Factors
#
# Time t=0 with all spreads and weights
dfInstruments$InitialDiscountFactors <- exp(-(dfInstruments$InitialDiscountRate/100.0)*
  dfInstruments$Maturity)
# Time t=Horizon with time t=0 spreads and weights
dfInstruments$InitialDiscountFactorsAtHorizon <- exp(-(dfInstruments$InitialDiscountRateAtHorizon/100.0)*
  (dfInstruments$Maturity - Horizon))
# Time t=Horizon with all horizon base and spread rates and weights
dfInstruments$HorizonDiscountFactors <- exp(-(dfInstruments$HorizonDiscountRate/100.0)*
  (dfInstruments$Maturity - Horizon))
# Time t=Horizon with all horizon base and spread rates and weights (decomposition)
dfInstruments$HorizonDiscountFactorsBase <- exp(-(dfInstruments$HorizonDiscountRateBase/100.0)*
  (dfInstruments$Maturity - Horizon))
dfInstruments$HorizonDiscountFactorsSpread1 <- exp(-(dfInstruments$HorizonDiscountRateSpread1/100.0)*
  (dfInstruments$Maturity - Horizon))
dfInstruments$HorizonDiscountFactorsSpread2 <- exp(-(dfInstruments$HorizonDiscountRateSpread2/100.0)*
  (dfInstruments$Maturity - Horizon))
dfInstruments$HorizonDiscountFactorsSpread3 <- exp(-(dfInstruments$HorizonDiscountRateSpread3/100.0)*
  (dfInstruments$Maturity - Horizon))
dfInstruments$HorizonDiscountFactorsSpread4 <- exp(-(dfInstruments$HorizonDiscountRateSpread4/100.0)*
  (dfInstruments$Maturity - Horizon))
dfInstruments$HorizonDiscountFactorsSpread5 <- exp(-(dfInstruments$HorizonDiscountRateSpread5/100.0)*
  (dfInstruments$Maturity - Horizon))
#
# Present value of expected future cash flow
#
dfInstruments$InitialPVECF <- dfInstruments$ECF * dfInstruments$InitialDiscountFactors
dfInstruments$InitialPVECFAtHorizon <- dfInstruments$ECF * dfInstruments$InitialDiscountFactorsAtHorizon
dfInstruments$HorizonPVECF <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactors
dfInstruments$HorizonPVECFBase <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactorsBase
dfInstruments$HorizonPVECFSpread1 <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactorsSpread1
dfInstruments$HorizonPVECFSpread2 <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactorsSpread2
dfInstruments$HorizonPVECFSpread3 <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactorsSpread3
dfInstruments$HorizonPVECFSpread4 <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactorsSpread4
dfInstruments$HorizonPVECFSpread5 <- dfInstruments$ECF * dfInstruments$HorizonDiscountFactorsSpread5
#
# Balance sheets
#
dfPVBS <- dfInstruments
# dfPVBS$WBase <- NULL
# dfPVBS$WSpread1 <- NULL
# dfPVBS$WSpread2 <- NULL
# dfPVBS$WSpread3 <- NULL
# dfPVBS$WSpread4 <- NULL
# dfPVBS$WSpread5 <- NULL
dfPVBS$InitialBaseRate <- NULL
dfPVBS$InitialSpread1Rate <- NULL
dfPVBS$InitialSpread2Rate <- NULL
dfPVBS$InitialSpread3Rate <- NULL
dfPVBS$InitialSpread4Rate <- NULL
dfPVBS$InitialSpread5Rate <- NULL
dfPVBS$HorizonBaseRate <- NULL
dfPVBS$HorizonSpread1Rate <- NULL
dfPVBS$HorizonSpread2Rate <- NULL
dfPVBS$HorizonSpread3Rate <- NULL
dfPVBS$HorizonSpread4Rate <- NULL
dfPVBS$HorizonSpread5Rate <- NULL
dfPVBS <- dfPVBS[with(dfPVBS, order(Instrument)),]
#
# Reported Balance Sheet (no aggregation necessary, just user inputs)
#
dfReportedBalanceSheet <- dfPVBS[dfPVBS$Maturity < 0.0000011,] 
dfReportedBalanceSheet$StatedValue = dfReportedBalanceSheet$ECF
keeps <- c("Instrument","StatedValue")
dfReportedBalanceSheet = dfReportedBalanceSheet[keeps]
ReportedNW <- -sum(dfReportedBalanceSheet$StatedValue)
# Index for net worth
y <- as.character(MaxInstruments+1)
# Net worth, total assets, total liabilities
dfReportedBalanceSheet <- rbind(dfReportedBalanceSheet, y = c(MaxInstruments+1, ReportedNW))
dfReportedBalanceSheet <- rbind(dfReportedBalanceSheet, y = c(MaxInstruments+2, NA))
dfReportedBalanceSheet <- rbind(dfReportedBalanceSheet, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfReportedBalanceSheet$StatedValue[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfReportedBalanceSheet$StatedValue[NumberOfAssets+i] 
}
dfReportedBalanceSheet$StatedValue[MaxInstruments+2] <- TA
dfReportedBalanceSheet$StatedValue[MaxInstruments+3] <- TL
#
# Present Value Balance Sheet
#
dfPVBS <- dfPVBS[dfPVBS$Maturity > 0.0000011,]
dfPVBalanceSheet <- ddply(dfPVBS, .(Instrument), summarize, PVBS=sum(InitialPVECF))
dfPVBalanceSheet$EstimatedValue <- dfPVBalanceSheet$PVBS
keeps <- c("Instrument","EstimatedValue")
dfPVBalanceSheet = dfPVBalanceSheet[keeps]
EstimatedNW <- -sum(dfPVBalanceSheet$EstimatedValue)
dfPVBalanceSheet <- rbind(dfPVBalanceSheet, y = c(MaxInstruments+1, EstimatedNW))
dfPVBalanceSheet <- rbind(dfPVBalanceSheet, y = c(MaxInstruments+2, NA))
dfPVBalanceSheet <- rbind(dfPVBalanceSheet, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheet$EstimatedValue[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheet$EstimatedValue[NumberOfAssets+i] 
}
dfPVBalanceSheet$EstimatedValue[MaxInstruments+2] <- TA
dfPVBalanceSheet$EstimatedValue[MaxInstruments+3] <- TL
#
# Present Value Balance Sheet At Horizon
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizon <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizon=sum(InitialPVECFAtHorizon))
dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon <- dfPVBalanceSheetAtHorizon$PVBSAtHorizon
keeps <- c("Instrument","EstimatedValueAtHorizon")
dfPVBalanceSheetAtHorizon = dfPVBalanceSheetAtHorizon[keeps]
EstimatedNWAtHorizon <- -sum(dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon)
dfPVBalanceSheetAtHorizon <- rbind(dfPVBalanceSheetAtHorizon, y = c(MaxInstruments+1, EstimatedNWAtHorizon))
dfPVBalanceSheetAtHorizon <- rbind(dfPVBalanceSheetAtHorizon, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizon <- rbind(dfPVBalanceSheetAtHorizon, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizon$EstimatedValueAtHorizon[MaxInstruments+3] <- TL
dfPVBalanceSheetAtHorizonInitial <- dfPVBalanceSheetAtHorizon
#
# Insert Weights (at Horizon)
#
dfPVBSWAtHorizon <- Reduce(function(x, y) merge(x, y, all=TRUE), list(dfPVBS, dfPVBalanceSheetAtHorizon))
dfPVBSWAtHorizon$Weight <- dfPVBSWAtHorizon$InitialPVECFAtHorizon/dfPVBSWAtHorizon$EstimatedValueAtHorizon
#
# Present Value Balance Sheet At Horizon w Base (Spreads at Initial Values)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonBase <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonBase=sum(HorizonPVECFBase))
dfPVBalanceSheetAtHorizonBase$EstimatedValueAtHorizonBase <- dfPVBalanceSheetAtHorizonBase$PVBSAtHorizonBase
keeps <- c("Instrument","EstimatedValueAtHorizonBase")
dfPVBalanceSheetAtHorizonBase = dfPVBalanceSheetAtHorizonBase[keeps]
EstimatedNWAtHorizonBase <- -sum(dfPVBalanceSheetAtHorizonBase$EstimatedValueAtHorizonBase)
dfPVBalanceSheetAtHorizonBase <- rbind(dfPVBalanceSheetAtHorizonBase, y = c(MaxInstruments+1, EstimatedNWAtHorizonBase))
dfPVBalanceSheetAtHorizonBase <- rbind(dfPVBalanceSheetAtHorizonBase, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonBase <- rbind(dfPVBalanceSheetAtHorizonBase, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonBase$EstimatedValueAtHorizonBase[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonBase$EstimatedValueAtHorizonBase[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonBase$EstimatedValueAtHorizonBase[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonBase$EstimatedValueAtHorizonBase[MaxInstruments+3] <- TL
# dfPVBalanceSheetAtHorizonBase
#
# Present Value Balance Sheet At Horizon w Spread1 (Base and Other Spreads at Initial Values)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonSpread1 <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonSpread1=sum(HorizonPVECFSpread1))
dfPVBalanceSheetAtHorizonSpread1$EstimatedValueAtHorizonSpread1 <- dfPVBalanceSheetAtHorizonSpread1$PVBSAtHorizonSpread1
keeps <- c("Instrument","EstimatedValueAtHorizonSpread1")
dfPVBalanceSheetAtHorizonSpread1 = dfPVBalanceSheetAtHorizonSpread1[keeps]
EstimatedNWAtHorizonSpread1 <- -sum(dfPVBalanceSheetAtHorizonSpread1$EstimatedValueAtHorizonSpread1)
dfPVBalanceSheetAtHorizonSpread1 <- rbind(dfPVBalanceSheetAtHorizonSpread1, y = c(MaxInstruments+1, EstimatedNWAtHorizonSpread1))
dfPVBalanceSheetAtHorizonSpread1 <- rbind(dfPVBalanceSheetAtHorizonSpread1, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonSpread1 <- rbind(dfPVBalanceSheetAtHorizonSpread1, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonSpread1$EstimatedValueAtHorizonSpread1[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonSpread1$EstimatedValueAtHorizonSpread1[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonSpread1$EstimatedValueAtHorizonSpread1[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonSpread1$EstimatedValueAtHorizonSpread1[MaxInstruments+3] <- TL
#  dfPVBalanceSheetAtHorizonSpread1
#
# Present Value Balance Sheet At Horizon w Spread2 (Base and Other Spreads at Initial Values)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonSpread2 <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonSpread2=sum(HorizonPVECFSpread2))
dfPVBalanceSheetAtHorizonSpread2$EstimatedValueAtHorizonSpread2 <- dfPVBalanceSheetAtHorizonSpread2$PVBSAtHorizonSpread2
keeps <- c("Instrument","EstimatedValueAtHorizonSpread2")
dfPVBalanceSheetAtHorizonSpread2 = dfPVBalanceSheetAtHorizonSpread2[keeps]
EstimatedNWAtHorizonSpread2 <- -sum(dfPVBalanceSheetAtHorizonSpread2$EstimatedValueAtHorizonSpread2)
dfPVBalanceSheetAtHorizonSpread2 <- rbind(dfPVBalanceSheetAtHorizonSpread2, y = c(MaxInstruments+1, EstimatedNWAtHorizonSpread2))
dfPVBalanceSheetAtHorizonSpread2 <- rbind(dfPVBalanceSheetAtHorizonSpread2, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonSpread2 <- rbind(dfPVBalanceSheetAtHorizonSpread2, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonSpread2$EstimatedValueAtHorizonSpread2[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonSpread2$EstimatedValueAtHorizonSpread2[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonSpread2$EstimatedValueAtHorizonSpread2[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonSpread2$EstimatedValueAtHorizonSpread2[MaxInstruments+3] <- TL
#  dfPVBalanceSheetAtHorizonSpread2
#
# Present Value Balance Sheet At Horizon w Spread3 (Base and Other Spreads at Initial Values)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonSpread3 <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonSpread3=sum(HorizonPVECFSpread3))
dfPVBalanceSheetAtHorizonSpread3$EstimatedValueAtHorizonSpread3 <- dfPVBalanceSheetAtHorizonSpread3$PVBSAtHorizonSpread3
keeps <- c("Instrument","EstimatedValueAtHorizonSpread3")
dfPVBalanceSheetAtHorizonSpread3 = dfPVBalanceSheetAtHorizonSpread3[keeps]
EstimatedNWAtHorizonSpread3 <- -sum(dfPVBalanceSheetAtHorizonSpread3$EstimatedValueAtHorizonSpread3)
dfPVBalanceSheetAtHorizonSpread3 <- rbind(dfPVBalanceSheetAtHorizonSpread3, y = c(MaxInstruments+1, EstimatedNWAtHorizonSpread3))
dfPVBalanceSheetAtHorizonSpread3 <- rbind(dfPVBalanceSheetAtHorizonSpread3, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonSpread3 <- rbind(dfPVBalanceSheetAtHorizonSpread3, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonSpread3$EstimatedValueAtHorizonSpread3[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonSpread3$EstimatedValueAtHorizonSpread3[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonSpread3$EstimatedValueAtHorizonSpread3[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonSpread3$EstimatedValueAtHorizonSpread3[MaxInstruments+3] <- TL
#  dfPVBalanceSheetAtHorizonSpread3
#
# Present Value Balance Sheet At Horizon w Spread4 (Base and Other Spreads at Initial Values)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonSpread4 <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonSpread4=sum(HorizonPVECFSpread4))
dfPVBalanceSheetAtHorizonSpread4$EstimatedValueAtHorizonSpread4 <- dfPVBalanceSheetAtHorizonSpread4$PVBSAtHorizonSpread4
keeps <- c("Instrument","EstimatedValueAtHorizonSpread4")
dfPVBalanceSheetAtHorizonSpread4 = dfPVBalanceSheetAtHorizonSpread4[keeps]
EstimatedNWAtHorizonSpread4 <- -sum(dfPVBalanceSheetAtHorizonSpread4$EstimatedValueAtHorizonSpread4)
dfPVBalanceSheetAtHorizonSpread4 <- rbind(dfPVBalanceSheetAtHorizonSpread4, y = c(MaxInstruments+1, EstimatedNWAtHorizonSpread4))
dfPVBalanceSheetAtHorizonSpread4 <- rbind(dfPVBalanceSheetAtHorizonSpread4, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonSpread4 <- rbind(dfPVBalanceSheetAtHorizonSpread4, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonSpread4$EstimatedValueAtHorizonSpread4[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonSpread4$EstimatedValueAtHorizonSpread4[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonSpread4$EstimatedValueAtHorizonSpread4[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonSpread4$EstimatedValueAtHorizonSpread4[MaxInstruments+3] <- TL
#  dfPVBalanceSheetAtHorizonSpread4
#
# Present Value Balance Sheet At Horizon w Spread5 (Base and Other Spreads at Initial Values)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonSpread5 <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonSpread5=sum(HorizonPVECFSpread5))
dfPVBalanceSheetAtHorizonSpread5$EstimatedValueAtHorizonSpread5 <- dfPVBalanceSheetAtHorizonSpread5$PVBSAtHorizonSpread5
keeps <- c("Instrument","EstimatedValueAtHorizonSpread5")
dfPVBalanceSheetAtHorizonSpread5 = dfPVBalanceSheetAtHorizonSpread5[keeps]
EstimatedNWAtHorizonSpread5 <- -sum(dfPVBalanceSheetAtHorizonSpread5$EstimatedValueAtHorizonSpread5)
dfPVBalanceSheetAtHorizonSpread5 <- rbind(dfPVBalanceSheetAtHorizonSpread5, y = c(MaxInstruments+1, EstimatedNWAtHorizonSpread5))
dfPVBalanceSheetAtHorizonSpread5 <- rbind(dfPVBalanceSheetAtHorizonSpread5, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonSpread5 <- rbind(dfPVBalanceSheetAtHorizonSpread5, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonSpread5$EstimatedValueAtHorizonSpread5[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonSpread5$EstimatedValueAtHorizonSpread5[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonSpread5$EstimatedValueAtHorizonSpread5[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonSpread5$EstimatedValueAtHorizonSpread5[MaxInstruments+3] <- TL
#  dfPVBalanceSheetAtHorizonSpread5
#
# Present Value Balance Sheet At Horizon w Base and Spreads (All)
#
dfPVBSAtHorizon <- dfPVBS[dfPVBS$Maturity > Horizon - 0.000001,]
dfPVBalanceSheetAtHorizonAll <- ddply(dfPVBSAtHorizon, .(Instrument), summarize, PVBSAtHorizonAll=sum(HorizonPVECF))
dfPVBalanceSheetAtHorizonAll$EstimatedValueAtHorizonAll <- dfPVBalanceSheetAtHorizonAll$PVBSAtHorizonAll
keeps <- c("Instrument","EstimatedValueAtHorizonAll")
dfPVBalanceSheetAtHorizonAll = dfPVBalanceSheetAtHorizonAll[keeps]
EstimatedNWAtHorizonAll <- -sum(dfPVBalanceSheetAtHorizonAll$EstimatedValueAtHorizonAll)
dfPVBalanceSheetAtHorizonAll <- rbind(dfPVBalanceSheetAtHorizonAll, y = c(MaxInstruments+1, EstimatedNWAtHorizonAll))
dfPVBalanceSheetAtHorizonAll <- rbind(dfPVBalanceSheetAtHorizonAll, y = c(MaxInstruments+2, NA))
dfPVBalanceSheetAtHorizonAll <- rbind(dfPVBalanceSheetAtHorizonAll, y = c(MaxInstruments+3, NA))
TA <- 0.0
for(i in 1:NumberOfAssets){
  TA <- TA + dfPVBalanceSheetAtHorizonAll$EstimatedValueAtHorizonAll[i] 
}
TL <- 0.0
for(i in 1:NumberOfLiabilities){
  TL <- TL + dfPVBalanceSheetAtHorizonAll$EstimatedValueAtHorizonAll[NumberOfAssets+i] 
}
dfPVBalanceSheetAtHorizonAll$EstimatedValueAtHorizonAll[MaxInstruments+2] <- TA
dfPVBalanceSheetAtHorizonAll$EstimatedValueAtHorizonAll[MaxInstruments+3] <- TL
#
# Grandular static risk measures
#
dfStaticRiskMeasures <- dfPVBSWAtHorizon
keeps <- c("Instrument", "Maturity", "Weight", "WBase", "WSpread1", "WSpread2", "WSpread3", "WSpread4", "WSpread5")
dfStaticRiskMeasures = dfStaticRiskMeasures[keeps]
dfStaticRiskMeasures = dfStaticRiskMeasures[!is.na(dfStaticRiskMeasures$Maturity),] # Remove Net Worth
source("KM Base Rate Static Risk Measures.R")
source("KM Spread1 Rate Static Risk Measures.R")
source("KM Spread2 Rate Static Risk Measures.R")
source("KM Spread3 Rate Static Risk Measures.R")
source("KM Spread4 Rate Static Risk Measures.R")
source("KM Spread5 Rate Static Risk Measures.R")
